@@ -22,11 +22,17 @@ class ApiRoutes:
     # Agent paths
     AGENT_SESSION_CREATE: str = "/v1/agent-sessions"
     AGENT_RUN_CREATE: str = "/v1/agent-runs"
+    AGENT_CREATE: str = "/v2/agents"
 
+    # App paths
+    APP_CREATE: str = "/v2/apps"
     # Team paths
     TEAM_RUN_CREATE: str = "/v1/team-runs"
     TEAM_SESSION_CREATE: str = "/v1/team-sessions"
+    TEAM_CREATE: str = "/v2/teams"
 
+    # Workflow paths
+    WORKFLOW_CREATE: str = "/v2/workflows"
     # Telemetry paths
     # TODO: Update to use the new telemetry paths
     AGENT_TELEMETRY_SESSION_CREATE: str = "/v1/telemetry/agent/session/create"
@@ -37,3 +43,6 @@ class ApiRoutes:
     # Playground paths
     PLAYGROUND_ENDPOINT_CREATE: str = "/v1/playground/endpoint/create"
     PLAYGROUND_APP_DEPLOY: str = "/v1/playground/app/deploy"
+
+    # Eval paths
+    EVAL_RUN_CREATE: str = "/v2/eval-runs"
