@@ -18,3 +18,14 @@ class AgentRunCreate(BaseModel):
     run_id: Optional[str] = None
     run_data: Optional[Dict[str, Any]] = None
     agent_data: Optional[Dict[str, Any]] = None
+
+
+class AgentCreate(BaseModel):
+    """Data sent to API to create an Agent"""
+
+    agent_id: str
+    team_id: Optional[str] = None
+    app_id: Optional[str] = None
+    workflow_id: Optional[str] = None
+    name: Optional[str] = None
+    config: Dict[str, Any]
