@@ -37,8 +37,8 @@ from agno.media import Audio, Image, Video
 from agno.media import File as FileMedia
 from agno.memory.agent import AgentMemory
 from agno.memory.v2 import Memory
-from agno.run.response import RunEvent
-from agno.run.team import TeamRunResponse
+from agno.run.response import RunResponseErrorEvent, RunResponseEvent
+from agno.run.team import RunResponseErrorEvent as TeamRunResponseErrorEvent
 from agno.storage.session.agent import AgentSession
 from agno.storage.session.team import TeamSession
 from agno.storage.session.workflow import WorkflowSession
@@ -55,6 +55,7 @@ async def chat_response_streamer(
     images: Optional[List[Image]] = None,
     audio: Optional[List[Audio]] = None,
     videos: Optional[List[Video]] = None,
+    files: Optional[List[FileMedia]] = None,
 ) -> AsyncGenerator:
     try:
         run_response = await agent.arun(
@@ -64,19 +65,48 @@ async def chat_response_streamer(
             images=images,
             audio=audio,
             videos=videos,
+            files=files,
             stream=True,
             stream_intermediate_steps=True,
         )
         async for run_response_chunk in run_response:
-            run_response_chunk = cast(RunResponse, run_response_chunk)
             yield run_response_chunk.to_json()
     except Exception as e:
         import traceback
 
         traceback.print_exc(limit=3)
-        error_response = RunResponse(
+        error_response = RunResponseErrorEvent(
+            content=str(e),
+        )
+        yield error_response.to_json()
+        return
+
+
+async def agent_acontinue_run_streamer(
+    agent: Agent,
+    run_id: Optional[str] = None,
+    updated_tools: Optional[List] = None,
+    session_id: Optional[str] = None,
+    user_id: Optional[str] = None,
+) -> AsyncGenerator:
+    try:
+        continue_response = await agent.acontinue_run(
+            run_id=run_id,
+            updated_tools=updated_tools,
+            session_id=session_id,
+            user_id=user_id,
+            stream=True,
+            stream_intermediate_steps=True,
+        )
+        async for run_response_chunk in continue_response:
+            run_response_chunk = cast(RunResponseEvent, run_response_chunk)
+            yield run_response_chunk.to_json()
+    except Exception as e:
+        import traceback
+
+        traceback.print_exc(limit=3)
+        error_response = RunResponseErrorEvent(
             content=str(e),
-            event=RunEvent.run_error,
         )
         yield error_response.to_json()
         return
@@ -105,15 +135,13 @@ async def team_chat_response_streamer(
             stream_intermediate_steps=True,
         )
         async for run_response_chunk in run_response:
-            run_response_chunk = cast(TeamRunResponse, run_response_chunk)
             yield run_response_chunk.to_json()
     except Exception as e:
         import traceback
 
-        traceback.print_exc(limit=3)
-        error_response = TeamRunResponse(
+        traceback.print_exc()
+        error_response = TeamRunResponseErrorEvent(
             content=str(e),
-            event=RunEvent.run_error,
         )
         yield error_response.to_json()
         return
@@ -244,6 +272,7 @@ def get_async_playground_router(
         base64_images: List[Image] = []
         base64_audios: List[Audio] = []
         base64_videos: List[Video] = []
+        input_files: List[FileMedia] = []
 
         if files:
             for file in files:
@@ -282,56 +311,81 @@ def get_async_playground_router(
                         logger.error(f"Error processing video {file.filename}: {e}")
                         continue
                 else:
-                    # Check for knowledge base before processing documents
-                    if agent.knowledge is None:
-                        raise HTTPException(status_code=404, detail="KnowledgeBase not found")
-
+                    # Process document files
                     if file.content_type == "application/pdf":
                         from agno.document.reader.pdf_reader import PDFReader
 
                         contents = await file.read()
-                        pdf_file = BytesIO(contents)
-                        pdf_file.name = file.filename
-                        file_content = PDFReader().read(pdf_file)
+
+                        # If agent has knowledge base, load the document into it
                         if agent.knowledge is not None:
+                            pdf_file = BytesIO(contents)
+                            pdf_file.name = file.filename
+                            file_content = PDFReader().read(pdf_file)
                             agent.knowledge.load_documents(file_content)
+                        else:
+                            # If no knowledge base, treat as direct file input (similar to cookbook examples)
+                            input_files.append(FileMedia(content=contents))
+
                     elif file.content_type == "text/csv":
                         from agno.document.reader.csv_reader import CSVReader
 
                         contents = await file.read()
-                        csv_file = BytesIO(contents)
-                        csv_file.name = file.filename
-                        file_content = CSVReader().read(csv_file)
+
+                        # If agent has knowledge base, load the document into it
                         if agent.knowledge is not None:
+                            csv_file = BytesIO(contents)
+                            csv_file.name = file.filename
+                            file_content = CSVReader().read(csv_file)
                             agent.knowledge.load_documents(file_content)
+                        else:
+                            # If no knowledge base, treat as direct file input
+                            input_files.append(FileMedia(content=contents))
+
                     elif file.content_type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document":
                         from agno.document.reader.docx_reader import DocxReader
 
                         contents = await file.read()
-                        docx_file = BytesIO(contents)
-                        docx_file.name = file.filename
-                        file_content = DocxReader().read(docx_file)
+
+                        # If agent has knowledge base, load the document into it
                         if agent.knowledge is not None:
+                            docx_file = BytesIO(contents)
+                            docx_file.name = file.filename
+                            file_content = DocxReader().read(docx_file)
                             agent.knowledge.load_documents(file_content)
+                        else:
+                            # If no knowledge base, treat as direct file input
+                            input_files.append(FileMedia(content=contents))
+
                     elif file.content_type == "text/plain":
                         from agno.document.reader.text_reader import TextReader
 
                         contents = await file.read()
-                        text_file = BytesIO(contents)
-                        text_file.name = file.filename
-                        file_content = TextReader().read(text_file)
+
+                        # If agent has knowledge base, load the document into it
                         if agent.knowledge is not None:
+                            text_file = BytesIO(contents)
+                            text_file.name = file.filename
+                            file_content = TextReader().read(text_file)
                             agent.knowledge.load_documents(file_content)
+                        else:
+                            # If no knowledge base, treat as direct file input
+                            input_files.append(FileMedia(content=contents))
 
                     elif file.content_type == "application/json":
                         from agno.document.reader.json_reader import JSONReader
 
                         contents = await file.read()
-                        json_file = BytesIO(contents)
-                        json_file.name = file.filename
-                        file_content = JSONReader().read(json_file)
+
+                        # If agent has knowledge base, load the document into it
                         if agent.knowledge is not None:
+                            json_file = BytesIO(contents)
+                            json_file.name = file.filename
+                            file_content = JSONReader().read(json_file)
                             agent.knowledge.load_documents(file_content)
+                        else:
+                            # If no knowledge base, treat as direct file input
+                            input_files.append(FileMedia(content=contents))
                     else:
                         raise HTTPException(status_code=400, detail="Unsupported file type")
 
@@ -345,6 +399,7 @@ def get_async_playground_router(
                     images=base64_images if base64_images else None,
                     audio=base64_audios if base64_audios else None,
                     videos=base64_videos if base64_videos else None,
+                    files=input_files if input_files else None,
                 ),
                 media_type="text/event-stream",
             )
@@ -358,11 +413,75 @@ def get_async_playground_router(
                     images=base64_images if base64_images else None,
                     audio=base64_audios if base64_audios else None,
                     videos=base64_videos if base64_videos else None,
+                    files=input_files if input_files else None,
                     stream=False,
                 ),
             )
             return run_response.to_dict()
 
+    @playground_router.post("/agents/{agent_id}/runs/{run_id}/continue")
+    async def continue_agent_run(
+        agent_id: str,
+        run_id: str,
+        tools: str = Form(...),  # JSON string of tools
+        session_id: Optional[str] = Form(None),
+        user_id: Optional[str] = Form(None),
+        stream: bool = Form(True),
+    ):
+        # Parse the JSON string manually
+        try:
+            tools_data = json.loads(tools) if tools else None
+        except json.JSONDecodeError:
+            raise HTTPException(status_code=400, detail="Invalid JSON in tools field")
+
+        logger.debug(
+            f"AgentContinueRunRequest: run_id={run_id} session_id={session_id} user_id={user_id} agent_id={agent_id}"
+        )
+        agent = get_agent_by_id(agent_id, agents)
+        if agent is None:
+            raise HTTPException(status_code=404, detail="Agent not found")
+
+        if session_id is None or session_id == "":
+            logger.warning(
+                "Continuing run without session_id. This might lead to unexpected behavior if session context is important."
+            )
+        else:
+            logger.debug(f"Continuing run within session: {session_id}")
+
+        # Convert tools dict to ToolExecution objects if provided
+        updated_tools = None
+        if tools_data:
+            try:
+                from agno.models.response import ToolExecution
+
+                updated_tools = [ToolExecution.from_dict(tool) for tool in tools_data]
+            except Exception as e:
+                raise HTTPException(status_code=400, detail=f"Invalid structure or content for tools: {str(e)}")
+
+        if stream and agent.is_streamable:
+            return StreamingResponse(
+                agent_acontinue_run_streamer(
+                    agent,
+                    run_id=run_id,  # run_id from path
+                    updated_tools=updated_tools,
+                    session_id=session_id,
+                    user_id=user_id,
+                ),
+                media_type="text/event-stream",
+            )
+        else:
+            run_response_obj = cast(
+                RunResponse,
+                await agent.acontinue_run(
+                    run_id=run_id,  # run_id from path
+                    updated_tools=updated_tools,
+                    session_id=session_id,
+                    user_id=user_id,
+                    stream=False,
+                ),
+            )
+            return run_response_obj.to_dict()
+
     @playground_router.get("/agents/{agent_id}/sessions")
     async def get_all_agent_sessions(agent_id: str, user_id: Optional[str] = Query(None, min_length=1)):
         logger.debug(f"AgentSessionsRequest: {agent_id} {user_id}")
@@ -406,8 +525,8 @@ def get_async_playground_router(
             runs = agent_session.memory.get("runs")
             if runs is not None:
                 first_run = runs[0]
-                # This is how we know it is a RunResponse
-                if "content" in first_run or first_run.get("is_paused", False):
+                # This is how we know it is a RunResponse or RunPaused
+                if "content" in first_run or first_run.get("is_paused", False) or first_run.get("event") == "RunPaused":
                     agent_session_dict["runs"] = []
 
                     for run in runs:
@@ -784,10 +903,14 @@ def get_async_playground_router(
             runs = team_session.memory.get("runs")
             if runs is not None:
                 first_run = runs[0]
-                # This is how we know it is a RunResponse
-                if "content" in first_run or first_run.get("is_paused", False):
+                # This is how we know it is a RunResponse or RunPaused
+                if "content" in first_run or first_run.get("is_paused", False) or first_run.get("event") == "RunPaused":
                     team_session_dict["runs"] = []
                     for run in runs:
+                        # We skip runs that are not from the parent team
+                        if run.get("team_session_id") is not None and run.get("team_session_id") == session_id:
+                            continue
+
                         first_user_message = None
                         for msg in run.get("messages", []):
                             if msg.get("role") == "user" and msg.get("from_history", False) is False:
