@@ -1,4 +1,3 @@
-import platform
 from dataclasses import dataclass
 from typing import Dict, List, Optional, Tuple, Union
 
@@ -8,14 +7,6 @@ from agno.utils.log import logger
 try:
     from sentence_transformers import SentenceTransformer
 
-    if platform.system() == "Windows":
-        import numpy as np
-
-        numpy_version = np.__version__
-        if numpy_version.startswith("2"):
-            raise RuntimeError(
-                "Incompatible NumPy version detected. Please install NumPy 1.x by running 'pip install numpy<2'."
-            )
 except ImportError:
     raise ImportError("`sentence-transformers` not installed, please run `pip install sentence-transformers`")
 
@@ -23,11 +14,17 @@ except ImportError:
 @dataclass
 class SentenceTransformerEmbedder(Embedder):
     id: str = "sentence-transformers/all-MiniLM-L6-v2"
+    dimensions: int = 384
     sentence_transformer_client: Optional[SentenceTransformer] = None
+    prompt: Optional[str] = None
+    normalize_embeddings: bool = False
 
     def get_embedding(self, text: Union[str, List[str]]) -> List[float]:
-        model = SentenceTransformer(model_name_or_path=self.id)
-        embedding = model.encode(text)
+        if not self.sentence_transformer_client:
+            model = SentenceTransformer(model_name_or_path=self.id)
+        else:
+            model = self.sentence_transformer_client
+        embedding = model.encode(text, prompt=self.prompt, normalize_embeddings=self.normalize_embeddings)
         try:
             return embedding  # type: ignore
         except Exception as e:
