@@ -1,3 +1,4 @@
+import asyncio
 import gc
 import tracemalloc
 from dataclasses import dataclass, field
@@ -6,7 +7,7 @@ from typing import TYPE_CHECKING, Callable, List, Optional
 from uuid import uuid4
 
 from agno.api.schemas.evals import EvalType
-from agno.eval.utils import log_eval_run, store_result_in_file
+from agno.eval.utils import async_log_eval_run, log_eval_run, store_result_in_file
 from agno.utils.log import logger
 from agno.utils.timer import Timer
 
@@ -191,6 +192,16 @@ class PerformanceEval:
 
         return timer.elapsed
 
+    async def _async_measure_time(self) -> float:
+        """Measure execution time for a single run of the contextual async function."""
+        timer = Timer()
+
+        timer.start()
+        await self.func()
+        timer.stop()
+
+        return timer.elapsed
+
     def _measure_memory(self, baseline: float) -> float:
         """
         Measures peak memory usage using tracemalloc.
@@ -217,6 +228,58 @@ class PerformanceEval:
             logger.debug(f"[DEBUG] Raw peak usage: {peak_mib:.6f} MiB, Adjusted: {adjusted_usage:.6f} MiB")
         return adjusted_usage
 
+    def _parse_eval_run_data(self) -> dict:
+        """Parse the evaluation result into a dictionary with the data we want for monitoring."""
+        if self.result is None:
+            return {}
+
+        return {
+            "result": {
+                "avg_run_time": self.result.avg_run_time,
+                "min_run_time": self.result.min_run_time,
+                "max_run_time": self.result.max_run_time,
+                "std_dev_run_time": self.result.std_dev_run_time,
+                "median_run_time": self.result.median_run_time,
+                "p95_run_time": self.result.p95_run_time,
+                "avg_memory_usage": self.result.avg_memory_usage,
+                "min_memory_usage": self.result.min_memory_usage,
+                "max_memory_usage": self.result.max_memory_usage,
+                "std_dev_memory_usage": self.result.std_dev_memory_usage,
+                "median_memory_usage": self.result.median_memory_usage,
+                "p95_memory_usage": self.result.p95_memory_usage,
+            },
+            "runs": [
+                {"runtime": runtime, "memory": memory_usage}
+                for runtime, memory_usage in zip(self.result.run_times, self.result.memory_usages)
+            ],
+        }
+
+    async def _async_measure_memory(self, baseline: float) -> float:
+        """
+        Measures peak memory usage using tracemalloc for async functions.
+        Subtracts the provided 'baseline' to compute an adjusted usage.
+        """
+
+        # Clear memory before measurement
+        gc.collect()
+        # Start tracing memory
+        tracemalloc.start()
+
+        await self.func()
+
+        # Get peak memory usage
+        current, peak = tracemalloc.get_traced_memory()
+        # Stop tracing memory
+        tracemalloc.stop()
+
+        # Convert to MiB and subtract baseline
+        peak_mib = peak / 1024 / 1024
+        adjusted_usage = max(0, peak_mib - baseline)
+
+        if self.debug_mode:
+            logger.debug(f"[DEBUG] Raw peak usage: {peak_mib:.6f} MiB, Adjusted: {adjusted_usage:.6f} MiB")
+        return adjusted_usage
+
     def _compute_tracemalloc_baseline(self, samples: int = 3) -> float:
         """
         Runs tracemalloc multiple times with an empty function to establish
@@ -239,7 +302,7 @@ class PerformanceEval:
 
     def run(self, *, print_summary: bool = False, print_results: bool = False) -> PerformanceResult:
         """
-        Main method to perform the performance evaluation.
+        Main method to run the performance evaluation.
         1. Do optional warm-up runs.
         2. Measure runtime
         3. Measure memory
@@ -329,26 +392,114 @@ class PerformanceEval:
         if self.monitoring:
             log_eval_run(
                 run_id=self.eval_id,  # type: ignore
-                run_data={
-                    "result": {
-                        "avg_run_time": self.result.avg_run_time,
-                        "min_run_time": self.result.min_run_time,
-                        "max_run_time": self.result.max_run_time,
-                        "std_dev_run_time": self.result.std_dev_run_time,
-                        "median_run_time": self.result.median_run_time,
-                        "p95_run_time": self.result.p95_run_time,
-                        "avg_memory_usage": self.result.avg_memory_usage,
-                        "min_memory_usage": self.result.min_memory_usage,
-                        "max_memory_usage": self.result.max_memory_usage,
-                        "std_dev_memory_usage": self.result.std_dev_memory_usage,
-                        "median_memory_usage": self.result.median_memory_usage,
-                        "p95_memory_usage": self.result.p95_memory_usage,
-                    },
-                    "runs": [
-                        {"runtime": runtime, "memory": memory_usage}
-                        for runtime, memory_usage in zip(self.result.run_times, self.result.memory_usages)
-                    ],
-                },
+                run_data=self._parse_eval_run_data(),
+                eval_type=EvalType.PERFORMANCE,
+                name=self.name if self.name is not None else None,
+                evaluated_entity_name=self.func.__name__,
+            )
+
+        logger.debug(f"*********** Evaluation End: {self.eval_id} ***********")
+        return self.result
+
+    async def arun(self, *, print_summary: bool = False, print_results: bool = False) -> PerformanceResult:
+        """
+        Async method to run the performance evaluation of async functions.
+        1. Do optional warm-up runs.
+        2. Measure runtime
+        3. Measure memory
+        4. Collect results
+        5. Save results if requested
+        6. Print results as requested
+        7. Log results to the Agno platform if requested
+        """
+        # Validate the function to evaluate is async.
+        if not asyncio.iscoroutinefunction(self.func):
+            raise ValueError(
+                f"The provided function ({self.func.__name__}) is not async. Use the run() method for sync functions."
+            )
+
+        from rich.console import Console
+        from rich.live import Live
+        from rich.status import Status
+
+        run_times = []
+        memory_usages = []
+
+        logger.debug(f"************ Evaluation Start: {self.eval_id} ************")
+
+        # Add a spinner while running the evaluations
+        console = Console()
+        with Live(console=console, transient=True) as live_log:
+            # 1. Do optional warm-up runs.
+            for i in range(self.warmup_runs):
+                status = Status(f"Warm-up run {i + 1}/{self.warmup_runs}...", spinner="dots", speed=1.0)
+                live_log.update(status)
+                await self.func()  # Simply run the function without measuring
+                status.stop()
+
+            # 2. Measure runtime
+            if self.measure_runtime:
+                for i in range(self.num_iterations):
+                    status = Status(
+                        f"Runtime measurement {i + 1}/{self.num_iterations}...",
+                        spinner="dots",
+                        speed=1.0,
+                        refresh_per_second=10,
+                    )
+                    live_log.update(status)
+                    # Measure runtime
+                    elapsed_time = await self._async_measure_time()
+                    run_times.append(elapsed_time)
+
+                    logger.debug(f"Run {i + 1} - Time taken: {elapsed_time:.6f} seconds")
+                    status.stop()
+
+            # 3. Measure memory
+            if self.measure_memory:
+                # 3.1 Compute memory baseline
+                memory_baseline = 0.0
+                memory_baseline = self._compute_tracemalloc_baseline()
+                logger.debug(f"Computed memory baseline: {memory_baseline:.6f} MiB")
+
+                for i in range(self.num_iterations):
+                    status = Status(
+                        f"Memory measurement {i + 1}/{self.num_iterations}...",
+                        spinner="dots",
+                        speed=1.0,
+                        refresh_per_second=10,
+                    )
+                    live_log.update(status)
+
+                    # Measure memory
+                    usage = await self._async_measure_memory(memory_baseline)
+                    memory_usages.append(usage)
+                    logger.debug(f"Run {i + 1} - Memory usage: {usage:.6f} MiB (adjusted)")
+
+                    status.stop()
+
+        # 4. Collect results
+        self.result = PerformanceResult(run_times=run_times, memory_usages=memory_usages)
+
+        # 5. Save result to file if requested
+        if self.file_path_to_save_results is not None and self.result is not None:
+            store_result_in_file(
+                file_path=self.file_path_to_save_results,
+                name=self.name,
+                eval_id=self.eval_id,
+                result=self.result,
+            )
+
+        # 6. Print results if requested
+        if self.print_results or print_results:
+            self.result.print_results(console)
+        if self.print_summary or print_summary:
+            self.result.print_summary(console)
+
+        # 7. Log results to the Agno platform if requested
+        if self.monitoring:
+            await async_log_eval_run(
+                run_id=self.eval_id,  # type: ignore
+                run_data=self._parse_eval_run_data(),
                 eval_type=EvalType.PERFORMANCE,
                 name=self.name if self.name is not None else None,
                 evaluated_entity_name=self.func.__name__,
