@@ -15,6 +15,7 @@ from agno.memory.v2.schema import SessionSummary, UserMemory
 from agno.memory.v2.summarizer import SessionSummarizer
 from agno.models.base import Model
 from agno.models.message import Message
+from agno.run.base import RunStatus
 from agno.run.response import RunResponse
 from agno.run.team import TeamRunResponse
 from agno.utils.log import log_debug, log_warning, logger, set_log_level_to_debug, set_log_level_to_info
@@ -45,7 +46,14 @@ class TeamMemberInteraction:
 
     @classmethod
     def from_dict(cls, data: Dict[str, Any]) -> "TeamMemberInteraction":
-        return cls(member_name=data["member_name"], task=data["task"], response=RunResponse.from_dict(data["response"]))
+        if data["response"].get("agent_id"):
+            return cls(
+                member_name=data["member_name"], task=data["task"], response=RunResponse.from_dict(data["response"])
+            )
+        else:
+            return cls(
+                member_name=data["member_name"], task=data["task"], response=TeamRunResponse.from_dict(data["response"])
+            )
 
 
 @dataclass
@@ -265,7 +273,6 @@ class Memory:
 
     def get_session_summary(self, session_id: str, user_id: Optional[str] = None) -> Optional[SessionSummary]:
         """Get the session summary for a given user id"""
-
         if user_id is None:
             user_id = "default"
         if self.summaries is None:
@@ -437,7 +444,6 @@ class Memory:
             summary=summary_response.summary, topics=summary_response.topics, last_updated=datetime.now()
         )
         self.summaries.setdefault(user_id, {})[session_id] = session_summary  # type: ignore
-
         return session_summary
 
     def create_user_memories(
@@ -694,15 +700,21 @@ class Memory:
     def get_messages_from_last_n_runs(
         self,
         session_id: str,
+        agent_id: Optional[str] = None,
+        team_id: Optional[str] = None,
         last_n: Optional[int] = None,
         skip_role: Optional[str] = None,
+        skip_status: Optional[List[RunStatus]] = None,
         skip_history_messages: bool = True,
     ) -> List[Message]:
         """Returns the messages from the last_n runs, excluding previously tagged history messages.
         Args:
             session_id: The session id to get the messages from.
+            agent_id: The id of the agent to get the messages from.
+            team_id: The id of the team to get the messages from.
             last_n: The number of runs to return from the end of the conversation. Defaults to all runs.
             skip_role: Skip messages with this role.
+            skip_status: Skip messages with this status.
             skip_history_messages: Skip messages that were tagged as history in previous runs.
         Returns:
             A list of Messages from the specified runs, excluding history messages.
@@ -710,7 +722,20 @@ class Memory:
         if not self.runs:
             return []
 
+        if skip_status is None:
+            skip_status = [RunStatus.paused, RunStatus.cancelled, RunStatus.error]
+
         session_runs = self.runs.get(session_id, [])
+        # Filter by agent_id and team_id
+        if agent_id:
+            session_runs = [run for run in session_runs if hasattr(run, "agent_id") and run.agent_id == agent_id]  # type: ignore
+        if team_id:
+            session_runs = [run for run in session_runs if hasattr(run, "team_id") and run.team_id == team_id]  # type: ignore
+
+        # Filter by status
+        session_runs = [run for run in session_runs if hasattr(run, "status") and run.status not in skip_status]  # type: ignore
+
+        # Filter by last_n
         runs_to_process = session_runs[-last_n:] if last_n is not None else session_runs
         messages_from_history = []
         system_message = None
@@ -1080,3 +1105,21 @@ class Memory:
                 if interaction.response.audio:
                     audio.extend(interaction.response.audio)
         return audio
+
+    def __deepcopy__(self, memo):
+        from copy import deepcopy
+
+        # Create a new instance without calling __init__
+        cls = self.__class__
+        copied_obj = cls.__new__(cls)
+        memo[id(self)] = copied_obj
+
+        # Deep copy attributes
+        for k, v in self.__dict__.items():
+            # Reuse db
+            if k in {"db", "memory_manager", "summary_manager", "team_context"}:
+                setattr(copied_obj, k, v)
+            else:
+                setattr(copied_obj, k, deepcopy(v, memo))
+
+        return copied_obj
