@@ -1,4 +1,13 @@
-from agno.models.azure.ai_foundry import AzureAIFoundry
+try:
+    from agno.models.azure.ai_foundry import AzureAIFoundry
+except ImportError:
+
+    class AzureAIFoundry:  # type: ignore
+        def __init__(self, *args, **kwargs):
+            raise ImportError(
+                "`azure-ai-inference` not installed. Please install it via `pip install azure-ai-inference aiohttp`"
+            )
+
 
 try:
     from agno.models.azure.openai_chat import AzureOpenAI
@@ -7,9 +16,3 @@ except ImportError:
     class AzureOpenAI:  # type: ignore
         def __init__(self, *args, **kwargs):
             raise ImportError("`openai` not installed. Please install it via `pip install openai`")
-
-
-__all__ = [
-    "AzureAIFoundry",
-    "AzureOpenAI",
-]
