@@ -1 +1,5 @@
 from agno.models.deepinfra.deepinfra import DeepInfra
+
+__all__ = [
+    "DeepInfra",
+]
