@@ -1 +1,5 @@
 from agno.models.lmstudio.lmstudio import LMStudio
+
+__all__ = [
+    "LMStudio",
+]
