@@ -20,3 +20,6 @@ class LMStudio(OpenAILike):
     provider: str = "LMStudio"
 
     base_url: str = "http://127.0.0.1:1234/v1"
+
+    supports_native_structured_outputs: bool = False
+    supports_json_schema_outputs: bool = True
