@@ -1,14 +1,14 @@
 from dataclasses import asdict, dataclass, field
 from enum import Enum
 from time import time
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel
 
 from agno.media import AudioArtifact, AudioResponse, ImageArtifact, VideoArtifact
-from agno.models.message import Citations, Message, MessageReferences
+from agno.models.message import Citations, Message
 from agno.models.response import ToolExecution
-from agno.reasoning.step import ReasoningStep
+from agno.run.base import BaseRunResponseEvent, RunResponseExtraData, RunStatus
 from agno.utils.log import logger
 
 
@@ -16,7 +16,7 @@ class RunEvent(str, Enum):
     """Events that can be sent by the run() functions"""
 
     run_started = "RunStarted"
-    run_response = "RunResponse"
+    run_response_content = "RunResponseContent"
     run_completed = "RunCompleted"
     run_error = "RunError"
     run_cancelled = "RunCancelled"
@@ -31,53 +31,182 @@ class RunEvent(str, Enum):
     reasoning_step = "ReasoningStep"
     reasoning_completed = "ReasoningCompleted"
 
-    updating_memory = "UpdatingMemory"
-
-    workflow_started = "WorkflowStarted"
-    workflow_completed = "WorkflowCompleted"
+    memory_update_started = "MemoryUpdateStarted"
+    memory_update_completed = "MemoryUpdateCompleted"
 
 
 @dataclass
-class RunResponseExtraData:
-    references: Optional[List[MessageReferences]] = None
-    add_messages: Optional[List[Message]] = None
-    reasoning_steps: Optional[List[ReasoningStep]] = None
-    reasoning_messages: Optional[List[Message]] = None
+class BaseAgentRunResponseEvent(BaseRunResponseEvent):
+    created_at: int = field(default_factory=lambda: int(time()))
+    event: str = ""
+    agent_id: str = ""
+    agent_name: str = ""
+    run_id: Optional[str] = None
+    session_id: Optional[str] = None
+    team_session_id: Optional[str] = None
 
-    def to_dict(self) -> Dict[str, Any]:
-        _dict = {}
-        if self.add_messages is not None:
-            _dict["add_messages"] = [m.to_dict() for m in self.add_messages]
-        if self.reasoning_messages is not None:
-            _dict["reasoning_messages"] = [m.to_dict() for m in self.reasoning_messages]
-        if self.reasoning_steps is not None:
-            _dict["reasoning_steps"] = [rs.model_dump() for rs in self.reasoning_steps]
-        if self.references is not None:
-            _dict["references"] = [r.model_dump() for r in self.references]
-        return _dict
+    # For backwards compatibility
+    content: Optional[Any] = None
 
-    @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> "RunResponseExtraData":
-        add_messages = data.pop("add_messages", None)
-        add_messages = [Message.model_validate(message) for message in add_messages] if add_messages else None
 
-        reasoning_steps = data.pop("reasoning_steps", None)
-        reasoning_steps = [ReasoningStep.model_validate(step) for step in reasoning_steps] if reasoning_steps else None
+@dataclass
+class RunResponseStartedEvent(BaseAgentRunResponseEvent):
+    """Event sent when the run starts"""
 
-        reasoning_messages = data.pop("reasoning_messages", None)
-        reasoning_messages = (
-            [Message.model_validate(message) for message in reasoning_messages] if reasoning_messages else None
-        )
+    event: str = RunEvent.run_started.value
+    model: str = ""
+    model_provider: str = ""
 
-        references = data.pop("references", None)
-        references = [MessageReferences.model_validate(reference) for reference in references] if references else None
 
-        return cls(
-            add_messages=add_messages,
-            reasoning_steps=reasoning_steps,
-            reasoning_messages=reasoning_messages,
-            references=references,
-        )
+@dataclass
+class RunResponseContentEvent(BaseAgentRunResponseEvent):
+    """Main event for each delta of the RunResponse"""
+
+    event: str = RunEvent.run_response_content.value
+    content: Optional[Any] = None
+    content_type: str = "str"
+    thinking: Optional[str] = None
+    citations: Optional[Citations] = None
+    response_audio: Optional[AudioResponse] = None  # Model audio response
+    image: Optional[ImageArtifact] = None  # Image attached to the response
+    extra_data: Optional[RunResponseExtraData] = None
+
+
+@dataclass
+class RunResponseCompletedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.run_completed.value
+    content: Optional[Any] = None
+    content_type: str = "str"
+    reasoning_content: Optional[str] = None
+    thinking: Optional[str] = None
+    citations: Optional[Citations] = None
+    images: Optional[List[ImageArtifact]] = None  # Images attached to the response
+    videos: Optional[List[VideoArtifact]] = None  # Videos attached to the response
+    audio: Optional[List[AudioArtifact]] = None  # Audio attached to the response
+    response_audio: Optional[AudioResponse] = None  # Model audio response
+    extra_data: Optional[RunResponseExtraData] = None
+
+
+@dataclass
+class RunResponsePausedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.run_paused.value
+    tools: Optional[List[ToolExecution]] = None
+
+    @property
+    def is_paused(self):
+        return True
+
+
+@dataclass
+class RunResponseContinuedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.run_continued.value
+
+
+@dataclass
+class RunResponseErrorEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.run_error.value
+    content: Optional[str] = None
+
+
+@dataclass
+class RunResponseCancelledEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.run_cancelled.value
+    reason: Optional[str] = None
+
+    @property
+    def is_cancelled(self):
+        return True
+
+
+@dataclass
+class MemoryUpdateStartedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.memory_update_started.value
+
+
+@dataclass
+class MemoryUpdateCompletedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.memory_update_completed.value
+
+
+@dataclass
+class ReasoningStartedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.reasoning_started.value
+
+
+@dataclass
+class ReasoningStepEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.reasoning_step.value
+    content: Optional[Any] = None
+    content_type: str = "str"
+    reasoning_content: str = ""
+
+
+@dataclass
+class ReasoningCompletedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.reasoning_completed.value
+    content: Optional[Any] = None
+    content_type: str = "str"
+
+
+@dataclass
+class ToolCallStartedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.tool_call_started.value
+    tool: Optional[ToolExecution] = None
+
+
+@dataclass
+class ToolCallCompletedEvent(BaseAgentRunResponseEvent):
+    event: str = RunEvent.tool_call_completed.value
+    tool: Optional[ToolExecution] = None
+    content: Optional[Any] = None
+    images: Optional[List[ImageArtifact]] = None  # Images produced by the tool call
+    videos: Optional[List[VideoArtifact]] = None  # Videos produced by the tool call
+    audio: Optional[List[AudioArtifact]] = None  # Audio produced by the tool call
+
+
+RunResponseEvent = Union[
+    RunResponseStartedEvent,
+    RunResponseContentEvent,
+    RunResponseCompletedEvent,
+    RunResponseErrorEvent,
+    RunResponseCancelledEvent,
+    RunResponsePausedEvent,
+    RunResponseContinuedEvent,
+    ReasoningStartedEvent,
+    ReasoningStepEvent,
+    ReasoningCompletedEvent,
+    MemoryUpdateStartedEvent,
+    MemoryUpdateCompletedEvent,
+    ToolCallStartedEvent,
+    ToolCallCompletedEvent,
+]
+
+
+# Map event string to dataclass
+RUN_EVENT_TYPE_REGISTRY = {
+    RunEvent.run_started.value: RunResponseStartedEvent,
+    RunEvent.run_response_content.value: RunResponseContentEvent,
+    RunEvent.run_completed.value: RunResponseCompletedEvent,
+    RunEvent.run_error.value: RunResponseErrorEvent,
+    RunEvent.run_cancelled.value: RunResponseCancelledEvent,
+    RunEvent.run_paused.value: RunResponsePausedEvent,
+    RunEvent.run_continued.value: RunResponseContinuedEvent,
+    RunEvent.reasoning_started.value: ReasoningStartedEvent,
+    RunEvent.reasoning_step.value: ReasoningStepEvent,
+    RunEvent.reasoning_completed.value: ReasoningCompletedEvent,
+    RunEvent.memory_update_started.value: MemoryUpdateStartedEvent,
+    RunEvent.memory_update_completed.value: MemoryUpdateCompletedEvent,
+    RunEvent.tool_call_started.value: ToolCallStartedEvent,
+    RunEvent.tool_call_completed.value: ToolCallCompletedEvent,
+}
+
+
+def run_response_event_from_dict(data: dict) -> BaseRunResponseEvent:
+    event_type = data.get("event", "")
+    cls = RUN_EVENT_TYPE_REGISTRY.get(event_type)
+    if not cls:
+        raise ValueError(f"Unknown event type: {event_type}")
+    return cls.from_dict(data)  # type: ignore
 
 
 @dataclass
@@ -88,14 +217,15 @@ class RunResponse:
     content_type: str = "str"
     thinking: Optional[str] = None
     reasoning_content: Optional[str] = None
-    event: str = RunEvent.run_response.value
     messages: Optional[List[Message]] = None
     metrics: Optional[Dict[str, Any]] = None
     model: Optional[str] = None
     model_provider: Optional[str] = None
     run_id: Optional[str] = None
     agent_id: Optional[str] = None
+    agent_name: Optional[str] = None
     session_id: Optional[str] = None
+    team_session_id: Optional[str] = None
     workflow_id: Optional[str] = None
     tools: Optional[List[ToolExecution]] = None
     formatted_tool_calls: Optional[List[str]] = None
@@ -107,11 +237,17 @@ class RunResponse:
     extra_data: Optional[RunResponseExtraData] = None
     created_at: int = field(default_factory=lambda: int(time()))
 
+    events: Optional[List[RunResponseEvent]] = None
+
+    status: RunStatus = RunStatus.running
+
     @property
     def is_paused(self):
-        if self.event == RunEvent.run_paused:
-            return True
-        return False
+        return self.status == RunStatus.paused
+
+    @property
+    def is_cancelled(self):
+        return self.status == RunStatus.cancelled
 
     @property
     def tools_requiring_confirmation(self):
@@ -130,8 +266,26 @@ class RunResponse:
             k: v
             for k, v in asdict(self).items()
             if v is not None
-            and k not in ["messages", "tools", "extra_data", "images", "videos", "audio", "response_audio", "citations"]
+            and k
+            not in [
+                "messages",
+                "tools",
+                "extra_data",
+                "images",
+                "videos",
+                "audio",
+                "response_audio",
+                "citations",
+                "events",
+            ]
         }
+
+        if self.events is not None:
+            _dict["events"] = [e.to_dict() for e in self.events]
+
+        if self.status is not None:
+            _dict["status"] = self.status.value if isinstance(self.status, RunStatus) else self.status
+
         if self.messages is not None:
             _dict["messages"] = [m.to_dict() for m in self.messages]
 
@@ -202,6 +356,9 @@ class RunResponse:
 
     @classmethod
     def from_dict(cls, data: Dict[str, Any]) -> "RunResponse":
+        events = data.pop("events", None)
+        events = [run_response_event_from_dict(event) for event in events] if events else None
+
         messages = data.pop("messages", None)
         messages = [Message.model_validate(message) for message in messages] if messages else None
 
@@ -220,7 +377,20 @@ class RunResponse:
         response_audio = data.pop("response_audio", None)
         response_audio = AudioResponse.model_validate(response_audio) if response_audio else None
 
-        return cls(messages=messages, tools=tools, images=images, videos=videos, response_audio=response_audio, **data)
+        # To make it backwards compatible
+        if "event" in data:
+            data.pop("event")
+
+        return cls(
+            messages=messages,
+            tools=tools,
+            images=images,
+            audio=audio,
+            videos=videos,
+            response_audio=response_audio,
+            events=events,
+            **data,
+        )
 
     def get_content_as_string(self, **kwargs) -> str:
         import json
