@@ -1,7 +1,7 @@
 from functools import update_wrapper, wraps
 from typing import Any, Callable, Dict, List, Optional, TypeVar, Union, overload
 
-from agno.tools.function import Function
+from agno.tools.function import Function, get_entrypoint_docstring
 from agno.utils.log import logger
 
 # Type variable for better type hints
@@ -24,6 +24,10 @@ def tool(
     sanitize_arguments: Optional[bool] = None,
     show_result: Optional[bool] = None,
     stop_after_tool_call: Optional[bool] = None,
+    requires_confirmation: Optional[bool] = None,
+    requires_user_input: Optional[bool] = None,
+    user_input_fields: Optional[List[str]] = None,
+    external_execution: Optional[bool] = None,
     pre_hook: Optional[Callable] = None,
     post_hook: Optional[Callable] = None,
     tool_hooks: Optional[List[Callable]] = None,
@@ -44,13 +48,17 @@ def tool(*args, **kwargs) -> Union[Function, Callable[[F], Function]]:
         name: Optional[str] - Override for the function name
         description: Optional[str] - Override for the function description
         strict: Optional[bool] - Flag for strict parameter checking
-        sanitize_arguments: Optional[bool] - If True, arguments are sanitized before passing to function
+        sanitize_arguments: Optional[bool] - If True, arguments are sanitized before passing to function (Deprecated)
         instructions: Optional[str] - Instructions for using the tool
         add_instructions: bool - If True, add instructions to the system message
         show_result: Optional[bool] - If True, shows the result after function call
         stop_after_tool_call: Optional[bool] - If True, the agent will stop after the function call.
-        pre_hook: Optional[Callable] - Hook that runs before the function is executed (deprecated, use tool_execution_hook instead).
-        post_hook: Optional[Callable] - Hook that runs after the function is executed (deprecated, use tool_execution_hook instead).
+        requires_confirmation: Optional[bool] - If True, the function will require user confirmation before execution
+        requires_user_input: Optional[bool] - If True, the function will require user input before execution
+        user_input_fields: Optional[List[str]] - List of fields that will be provided to the function as user input
+        external_execution: Optional[bool] - If True, the function will be executed outside of the agent's context
+        pre_hook: Optional[Callable] - Hook that runs before the function is executed.
+        post_hook: Optional[Callable] - Hook that runs after the function is executed.
         tool_hooks: Optional[List[Callable]] - List of hooks that run before and after the function is executed.
         cache_results: bool - If True, enable caching of function results
         cache_dir: Optional[str] - Directory to store cache files
@@ -83,6 +91,10 @@ def tool(*args, **kwargs) -> Union[Function, Callable[[F], Function]]:
             "sanitize_arguments",
             "show_result",
             "stop_after_tool_call",
+            "requires_confirmation",
+            "requires_user_input",
+            "user_input_fields",
+            "external_execution",
             "pre_hook",
             "post_hook",
             "tool_hooks",
@@ -99,8 +111,21 @@ def tool(*args, **kwargs) -> Union[Function, Callable[[F], Function]]:
             f"Invalid tool configuration arguments: {invalid_kwargs}. Valid arguments are: {sorted(VALID_KWARGS)}"
         )
 
+    # Check that only one of requires_user_input, requires_confirmation, and external_execution is set at the same time
+    exclusive_flags = [
+        kwargs.get("requires_user_input", False),
+        kwargs.get("requires_confirmation", False),
+        kwargs.get("external_execution", False),
+    ]
+    true_flags_count = sum(1 for flag in exclusive_flags if flag)
+
+    if true_flags_count > 1:
+        raise ValueError(
+            "Only one of 'requires_user_input', 'requires_confirmation', or 'external_execution' can be set to True at the same time."
+        )
+
     def decorator(func: F) -> Function:
-        from inspect import getdoc, isasyncgenfunction, iscoroutine, iscoroutinefunction
+        from inspect import isasyncgenfunction, iscoroutine, iscoroutinefunction
 
         @wraps(func)
         def sync_wrapper(*args: Any, **kwargs: Any) -> Any:
@@ -146,10 +171,18 @@ def tool(*args, **kwargs) -> Union[Function, Callable[[F], Function]]:
         # Preserve the original signature and metadata
         update_wrapper(wrapper, func)
 
+        if kwargs.get("requires_user_input", True):
+            kwargs["user_input_fields"] = kwargs.get("user_input_fields", [])
+
+        if kwargs.get("user_input_fields"):
+            kwargs["requires_user_input"] = True
+
         # Create Function instance with any provided kwargs
         tool_config = {
             "name": kwargs.get("name", func.__name__),
-            "description": kwargs.get("description", getdoc(func)),  # Get docstring if description not provided
+            "description": kwargs.get(
+                "description", get_entrypoint_docstring(wrapper)
+            ),  # Get docstring if description not provided
             "instructions": kwargs.get("instructions"),
             "add_instructions": kwargs.get("add_instructions", True),
             "entrypoint": wrapper,
