@@ -27,13 +27,16 @@ How to Get These Credentials:
      * Client Secret (GOOGLE_CLIENT_SECRET)
    - The Project ID (GOOGLE_PROJECT_ID) is visible in the project dropdown at the top of the page
 
-5. Set up environment variables:
+5. Add auth redirect URI:
+   - Go to https://console.cloud.google.com/auth/clients and add the redirect URI as http://127.0.0.1/
+
+6. Set up environment variables:
    Create a .envrc file in your project root with:
    ```
    export GOOGLE_CLIENT_ID=your_client_id_here
    export GOOGLE_CLIENT_SECRET=your_client_secret_here
    export GOOGLE_PROJECT_ID=your_project_id_here
-   export GOOGLE_REDIRECT_URI=http://localhost  # Default value
+   export GOOGLE_REDIRECT_URI=http://127.0.0.1/  # Default value
    ```
 
 Note: The first time you run the application, it will open a browser window for OAuth authentication.
@@ -41,16 +44,19 @@ A token.json file will be created to store the authentication credentials for fu
 """
 
 import base64
+import mimetypes
 import re
 from datetime import datetime, timedelta
 from functools import wraps
 from os import getenv
 from pathlib import Path
-from typing import List, Optional
+from typing import Any, List, Optional, Union
 
 from agno.tools import Toolkit
 
 try:
+    from email.mime.application import MIMEApplication
+    from email.mime.multipart import MIMEMultipart
     from email.mime.text import MIMEText
 
     from google.auth.transport.requests import Request
@@ -131,7 +137,6 @@ class GmailTools(Toolkit):
             token_path (Optional[str]): Path to token file. Defaults to None.
             scopes (Optional[List[str]]): Custom OAuth scopes. If None, uses DEFAULT_SCOPES.
         """
-        super().__init__(name="gmail_tools", **kwargs)
         self.creds = creds
         self.credentials_path = credentials_path
         self.token_path = token_path
@@ -161,28 +166,31 @@ class GmailTools(Toolkit):
             if read_scope not in self.scopes and write_scope not in self.scopes:
                 raise ValueError(f"The scope {read_scope} is required for email reading operations")
 
+        tools: List[Any] = []
         if get_latest_emails:
-            self.register(self.get_latest_emails)
+            tools.append(self.get_latest_emails)
         if get_emails_from_user:
-            self.register(self.get_emails_from_user)
+            tools.append(self.get_emails_from_user)
         if get_unread_emails:
-            self.register(self.get_unread_emails)
+            tools.append(self.get_unread_emails)
         if get_starred_emails:
-            self.register(self.get_starred_emails)
+            tools.append(self.get_starred_emails)
         if get_emails_by_context:
-            self.register(self.get_emails_by_context)
+            tools.append(self.get_emails_by_context)
         if get_emails_by_date:
-            self.register(self.get_emails_by_date)
+            tools.append(self.get_emails_by_date)
         if get_emails_by_thread:
-            self.register(self.get_emails_by_thread)
+            tools.append(self.get_emails_by_thread)
         if create_draft_email:
-            self.register(self.create_draft_email)
+            tools.append(self.create_draft_email)
         if send_email:
-            self.register(self.send_email)
+            tools.append(self.send_email)
         if send_email_reply:
-            self.register(self.send_email_reply)
+            tools.append(self.send_email_reply)
         if search_emails:
-            self.register(self.search_emails)
+            tools.append(self.search_emails)
+
+        super().__init__(name="gmail_tools", tools=tools, **kwargs)
 
     def _auth(self) -> None:
         """Authenticate with Gmail API"""
@@ -395,7 +403,14 @@ class GmailTools(Toolkit):
             return f"Unexpected error retrieving emails by date: {type(error).__name__}: {error}"
 
     @authenticate
-    def create_draft_email(self, to: str, subject: str, body: str, cc: Optional[str] = None) -> str:
+    def create_draft_email(
+        self,
+        to: str,
+        subject: str,
+        body: str,
+        cc: Optional[str] = None,
+        attachments: Optional[Union[str, List[str]]] = None,
+    ) -> str:
         """
         Create and save a draft email. to and cc are comma separated string of email ids
         Args:
@@ -403,18 +418,42 @@ class GmailTools(Toolkit):
             subject (str): Email subject
             body (str): Email body content
             cc (Optional[str]): Comma separated string of CC email addresses (optional)
+            attachments (Optional[Union[str, List[str]]]): File path(s) for attachments (optional)
 
         Returns:
             str: Stringified dictionary containing draft email details including id
         """
         self._validate_email_params(to, subject, body)
-        message = self._create_message(to.split(","), subject, body, cc.split(",") if cc else None)
+
+        # Process attachments
+        attachment_files = []
+        if attachments:
+            if isinstance(attachments, str):
+                attachment_files = [attachments]
+            else:
+                attachment_files = attachments
+
+            # Validate attachment files
+            for file_path in attachment_files:
+                if not Path(file_path).exists():
+                    raise ValueError(f"Attachment file not found: {file_path}")
+
+        message = self._create_message(
+            to.split(","), subject, body, cc.split(",") if cc else None, attachments=attachment_files
+        )
         draft = {"message": message}
         draft = self.service.users().drafts().create(userId="me", body=draft).execute()  # type: ignore
         return str(draft)
 
     @authenticate
-    def send_email(self, to: str, subject: str, body: str, cc: Optional[str] = None) -> str:
+    def send_email(
+        self,
+        to: str,
+        subject: str,
+        body: str,
+        cc: Optional[str] = None,
+        attachments: Optional[Union[str, List[str]]] = None,
+    ) -> str:
         """
         Send an email immediately. to and cc are comma separated string of email ids
         Args:
@@ -422,19 +461,43 @@ class GmailTools(Toolkit):
             subject (str): Email subject
             body (str): Email body content
             cc (Optional[str]): Comma separated string of CC email addresses (optional)
+            attachments (Optional[Union[str, List[str]]]): File path(s) for attachments (optional)
 
         Returns:
             str: Stringified dictionary containing sent email details including id
         """
         self._validate_email_params(to, subject, body)
+
+        # Process attachments
+        attachment_files = []
+        if attachments:
+            if isinstance(attachments, str):
+                attachment_files = [attachments]
+            else:
+                attachment_files = attachments
+
+            # Validate attachment files
+            for file_path in attachment_files:
+                if not Path(file_path).exists():
+                    raise ValueError(f"Attachment file not found: {file_path}")
+
         body = body.replace("\n", "<br>")
-        message = self._create_message(to.split(","), subject, body, cc.split(",") if cc else None)
+        message = self._create_message(
+            to.split(","), subject, body, cc.split(",") if cc else None, attachments=attachment_files
+        )
         message = self.service.users().messages().send(userId="me", body=message).execute()  # type: ignore
         return str(message)
 
     @authenticate
     def send_email_reply(
-        self, thread_id: str, message_id: str, to: str, subject: str, body: str, cc: Optional[str] = None
+        self,
+        thread_id: str,
+        message_id: str,
+        to: str,
+        subject: str,
+        body: str,
+        cc: Optional[str] = None,
+        attachments: Optional[Union[str, List[str]]] = None,
     ) -> str:
         """
         Respond to an existing email thread.
@@ -446,6 +509,7 @@ class GmailTools(Toolkit):
             subject (str): Email subject (prefixed with "Re:" if not already).
             body (str): Email body content.
             cc (Optional[str]): Comma-separated CC email addresses (optional).
+            attachments (Optional[Union[str, List[str]]]): File path(s) for attachments (optional)
 
         Returns:
             str: Stringified dictionary containing sent email details including id.
@@ -456,9 +520,28 @@ class GmailTools(Toolkit):
         if not subject.lower().startswith("re:"):
             subject = f"Re: {subject}"
 
+        # Process attachments
+        attachment_files = []
+        if attachments:
+            if isinstance(attachments, str):
+                attachment_files = [attachments]
+            else:
+                attachment_files = attachments
+
+            # Validate attachment files
+            for file_path in attachment_files:
+                if not Path(file_path).exists():
+                    raise ValueError(f"Attachment file not found: {file_path}")
+
         body = body.replace("\n", "<br>")
         message = self._create_message(
-            to.split(","), subject, body, cc.split(",") if cc else None, thread_id, message_id
+            to.split(","),
+            subject,
+            body,
+            cc.split(",") if cc else None,
+            thread_id,
+            message_id,
+            attachments=attachment_files,
         )
         message = self.service.users().messages().send(userId="me", body=message).execute()  # type: ignore
         return str(message)
@@ -509,9 +592,43 @@ class GmailTools(Toolkit):
         cc: Optional[List[str]] = None,
         thread_id: Optional[str] = None,
         message_id: Optional[str] = None,
+        attachments: Optional[List[str]] = None,
     ) -> dict:
         body = body.replace("\\n", "\n")
-        message = MIMEText(body, "html")
+
+        # Create multipart message if attachments exist, otherwise simple text message
+        message: Union[MIMEMultipart, MIMEText]
+        if attachments:
+            message = MIMEMultipart()
+
+            # Add the text body
+            text_part = MIMEText(body, "html")
+            message.attach(text_part)
+
+            # Add attachments
+            for file_path in attachments:
+                file_path_obj = Path(file_path)
+                if not file_path_obj.exists():
+                    continue
+
+                # Guess the content type based on the file extension
+                content_type, encoding = mimetypes.guess_type(file_path)
+                if content_type is None or encoding is not None:
+                    content_type = "application/octet-stream"
+
+                main_type, sub_type = content_type.split("/", 1)
+
+                # Read file and create attachment
+                with open(file_path, "rb") as file:
+                    attachment_data = file.read()
+
+                attachment = MIMEApplication(attachment_data, _subtype=sub_type)
+                attachment.add_header("Content-Disposition", "attachment", filename=file_path_obj.name)
+                message.attach(attachment)
+        else:
+            message = MIMEText(body, "html")
+
+        # Set headers
         message["to"] = ", ".join(to)
         message["from"] = "me"
         message["subject"] = subject
