@@ -1,7 +1,6 @@
 from contextlib import AsyncExitStack
 from dataclasses import asdict, dataclass
 from datetime import timedelta
-from os import environ
 from types import TracebackType
 from typing import Any, Dict, List, Literal, Optional, Union
 
@@ -13,7 +12,7 @@ from agno.utils.mcp import get_entrypoint_for_tool
 try:
     from mcp import ClientSession, StdioServerParameters
     from mcp.client.sse import sse_client
-    from mcp.client.stdio import stdio_client
+    from mcp.client.stdio import get_default_environment, stdio_client
     from mcp.client.streamable_http import streamablehttp_client
 except (ImportError, ModuleNotFoundError):
     raise ImportError("`mcp` not installed. Please install using `pip install mcp`")
@@ -129,11 +128,11 @@ class MCPTools(Toolkit):
         # Merge provided env with system env
         if env is not None:
             env = {
-                **environ,
+                **get_default_environment(),
                 **env,
             }
         else:
-            env = {**environ}
+            env = get_default_environment()
 
         if command is not None and transport not in ["sse", "streamable-http"]:
             from shlex import split
@@ -161,16 +160,16 @@ class MCPTools(Toolkit):
 
         # Create a new session using stdio_client, sse_client or streamablehttp_client based on transport
         if self.transport == "sse":
-            sse_params = asdict(self.server_params) if self.server_params is not None else {}
+            sse_params = asdict(self.server_params) if self.server_params is not None else {}  # type: ignore
             if "url" not in sse_params:
                 sse_params["url"] = self.url
-            self._context = sse_client(**sse_params)
+            self._context = sse_client(**sse_params)  # type: ignore
             client_timeout = min(self.timeout_seconds, sse_params.get("timeout", self.timeout_seconds))
         elif self.transport == "streamable-http":
-            streamable_http_params = asdict(self.server_params) if self.server_params is not None else {}
+            streamable_http_params = asdict(self.server_params) if self.server_params is not None else {}  # type: ignore
             if "url" not in streamable_http_params:
                 streamable_http_params["url"] = self.url
-            self._context = streamablehttp_client(**streamable_http_params)
+            self._context = streamablehttp_client(**streamable_http_params)  # type: ignore
             params_timeout = streamable_http_params.get("timeout", self.timeout_seconds)
             if isinstance(params_timeout, timedelta):
                 params_timeout = int(params_timeout.total_seconds())
@@ -184,7 +183,7 @@ class MCPTools(Toolkit):
         session_params = await self._context.__aenter__()  # type: ignore
         read, write = session_params[0:2]
 
-        self._session_context = ClientSession(read, write, read_timeout_seconds=timedelta(seconds=client_timeout))
+        self._session_context = ClientSession(read, write, read_timeout_seconds=timedelta(seconds=client_timeout))  # type: ignore
         self.session = await self._session_context.__aenter__()  # type: ignore
 
         # Initialize with the new session
@@ -330,11 +329,11 @@ class MultiMCPTools(Toolkit):
         # Merge provided env with system env
         if env is not None:
             env = {
-                **environ,
+                **get_default_environment(),
                 **env,
             }
         else:
-            env = {**environ}
+            env = get_default_environment()
 
         if commands is not None:
             from shlex import split
