@@ -1,6 +1,6 @@
 import json
 import os
-from typing import Optional
+from typing import Any, List, Optional
 
 from agno.tools.toolkit import Toolkit
 from agno.utils.log import logger
@@ -16,17 +16,20 @@ class WebexTools(Toolkit):
     def __init__(
         self, send_message: bool = True, list_rooms: bool = True, access_token: Optional[str] = None, **kwargs
     ):
-        super().__init__(name="webex", **kwargs)
         if access_token is None:
             access_token = os.getenv("WEBEX_ACCESS_TOKEN")
         if access_token is None:
             raise ValueError("Webex access token is not set. Please set the WEBEX_ACCESS_TOKEN environment variable.")
 
         self.client = WebexAPI(access_token=access_token)
+
+        tools: List[Any] = []
         if send_message:
-            self.register(self.send_message)
+            tools.append(self.send_message)
         if list_rooms:
-            self.register(self.list_rooms)
+            tools.append(self.list_rooms)
+
+        super().__init__(name="webex", tools=tools, **kwargs)
 
     def send_message(self, room_id: str, text: str) -> str:
         """
