@@ -12,12 +12,19 @@ except ImportError:
 from agno.document import Document
 from agno.embedder import Embedder
 from agno.reranker.base import Reranker
-from agno.utils.log import log_debug, log_info, logger
+from agno.utils.log import log_debug, log_info
 from agno.vectordb.base import VectorDb
 from agno.vectordb.distance import Distance
+from agno.vectordb.search import SearchType
+
+DEFAULT_DENSE_VECTOR_NAME = "dense"
+DEFAULT_SPARSE_VECTOR_NAME = "sparse"
+DEFAULT_SPARSE_MODEL = "Qdrant/bm25"
 
 
 class Qdrant(VectorDb):
+    """Vector DB implementation powered by Qdrant - https://qdrant.tech/"""
+
     def __init__(
         self,
         collection: str,
@@ -35,8 +42,37 @@ class Qdrant(VectorDb):
         host: Optional[str] = None,
         path: Optional[str] = None,
         reranker: Optional[Reranker] = None,
+        search_type: SearchType = SearchType.vector,
+        dense_vector_name: str = DEFAULT_DENSE_VECTOR_NAME,
+        sparse_vector_name: str = DEFAULT_SPARSE_VECTOR_NAME,
+        hybrid_fusion_strategy: models.Fusion = models.Fusion.RRF,
+        fastembed_kwargs: Optional[dict] = None,
         **kwargs,
     ):
+        """
+        Args:
+            collection (str): Name of the Qdrant collection.
+            embedder (Optional[Embedder]): Optional embedder for automatic vector generation.
+            distance (Distance): Distance metric to use (default: cosine).
+            location (Optional[str]): `":memory:"` for in-memory, or str used as `url`. If `None`, use default host/port.
+            url (Optional[str]): Full URL (scheme, host, port, prefix). Overrides host/port if provided.
+            port (Optional[int]): REST API port (default: 6333).
+            grpc_port (int): gRPC interface port (default: 6334).
+            prefer_grpc (bool): Prefer gRPC over REST if True.
+            https (Optional[bool]): Use HTTPS if True.
+            api_key (Optional[str]): API key for Qdrant Cloud authentication.
+            prefix (Optional[str]): URL path prefix (e.g., "service/v1").
+            timeout (Optional[float]): Request timeout (REST: default 5s, gRPC: unlimited).
+            host (Optional[str]): Qdrant host (default: "localhost" if not specified).
+            path (Optional[str]): Path for local persistence (QdrantLocal).
+            reranker (Optional[Reranker]): Optional reranker for result refinement.
+            search_type (SearchType): Whether to use vector, keyword or hybrid search.
+            dense_vector_name (str): Dense vector name.
+            sparse_vector_name (str): Sparse vector name.
+            hybrid_fusion_strategy (models.Fusion): Strategy for hybrid fusion.
+            fastembed_kwargs (Optional[dict]): Keyword args for `fastembed.SparseTextEmbedding.__init__()`.
+            **kwargs: Keyword args for `qdrant_client.QdrantClient.__init__()`.
+        """
         # Collection attributes
         self.collection: str = collection
 
@@ -46,6 +82,7 @@ class Qdrant(VectorDb):
 
             embedder = OpenAIEmbedder()
             log_info("Embedder not provided, using OpenAIEmbedder as default.")
+
         self.embedder: Embedder = embedder
         self.dimensions: Optional[int] = self.embedder.dimensions
 
@@ -77,6 +114,30 @@ class Qdrant(VectorDb):
         # Qdrant client kwargs
         self.kwargs = kwargs
 
+        self.search_type = search_type
+        self.dense_vector_name = dense_vector_name
+        self.sparse_vector_name = sparse_vector_name
+        self.hybrid_fusion_strategy = hybrid_fusion_strategy
+
+        # TODO(v2.0.0): Remove backward compatibility for unnamed vectors
+        # TODO(v2.0.0): Make named vectors mandatory and simplify the codebase
+        self.use_named_vectors = search_type in [SearchType.hybrid]
+
+        if self.search_type in [SearchType.keyword, SearchType.hybrid]:
+            try:
+                from fastembed import SparseTextEmbedding  # type: ignore
+
+                default_kwargs = {"model_name": DEFAULT_SPARSE_MODEL}
+                if fastembed_kwargs:
+                    default_kwargs.update(fastembed_kwargs)
+
+                self.sparse_encoder = SparseTextEmbedding(**default_kwargs)
+
+            except ImportError as e:
+                raise ImportError(
+                    "To use keyword/hybrid search, install the `fastembed` extra with `pip install fastembed`."
+                ) from e
+
     @property
     def client(self) -> QdrantClient:
         if self._client is None:
@@ -119,7 +180,6 @@ class Qdrant(VectorDb):
         return self._async_client
 
     def create(self) -> None:
-        # Collection distance
         _distance = models.Distance.COSINE
         if self.distance == Distance.l2:
             _distance = models.Distance.EUCLID
@@ -128,9 +188,21 @@ class Qdrant(VectorDb):
 
         if not self.exists():
             log_debug(f"Creating collection: {self.collection}")
+
+            # Configure vectors based on search type
+            if self.search_type == SearchType.vector:
+                # Maintain backward compatibility with unnamed vectors
+                vectors_config = models.VectorParams(size=self.dimensions, distance=_distance)
+            else:
+                # Use named vectors for hybrid search
+                vectors_config = {self.dense_vector_name: models.VectorParams(size=self.dimensions, distance=_distance)}  # type: ignore
+
             self.client.create_collection(
                 collection_name=self.collection,
-                vectors_config=models.VectorParams(size=self.dimensions, distance=_distance),
+                vectors_config=vectors_config,
+                sparse_vectors_config={self.sparse_vector_name: models.SparseVectorParams()}
+                if self.search_type in [SearchType.keyword, SearchType.hybrid]
+                else None,
             )
 
     async def async_create(self) -> None:
@@ -144,9 +216,21 @@ class Qdrant(VectorDb):
 
         if not await self.async_exists():
             log_debug(f"Creating collection asynchronously: {self.collection}")
+
+            # Configure vectors based on search type
+            if self.search_type == SearchType.vector:
+                # Maintain backward compatibility with unnamed vectors
+                vectors_config = models.VectorParams(size=self.dimensions, distance=_distance)
+            else:
+                # Use named vectors for hybrid search
+                vectors_config = {self.dense_vector_name: models.VectorParams(size=self.dimensions, distance=_distance)}  # type: ignore
+
             await self.async_client.create_collection(
                 collection_name=self.collection,
-                vectors_config=models.VectorParams(size=self.dimensions, distance=_distance),
+                vectors_config=vectors_config,
+                sparse_vectors_config={self.sparse_vector_name: models.SparseVectorParams()}
+                if self.search_type in [SearchType.keyword, SearchType.hybrid]
+                else None,
             )
 
     def doc_exists(self, document: Document) -> bool:
@@ -230,10 +314,29 @@ class Qdrant(VectorDb):
         log_debug(f"Inserting {len(documents)} documents")
         points = []
         for document in documents:
-            document.embed(embedder=self.embedder)
             cleaned_content = document.content.replace("\x00", "\ufffd")
             doc_id = md5(cleaned_content.encode()).hexdigest()
 
+            # TODO(v2.0.0): Remove conditional vector naming logic
+            if self.use_named_vectors:
+                vector = {self.dense_vector_name: document.embedding}
+            else:
+                vector = document.embedding  # type: ignore
+
+            if self.search_type == SearchType.vector:
+                # For vector search, maintain backward compatibility with unnamed vectors
+                document.embed(embedder=self.embedder)
+                vector = document.embedding  # type: ignore
+            else:
+                # For other search types, use named vectors
+                vector = {}
+                if self.search_type in [SearchType.hybrid]:
+                    document.embed(embedder=self.embedder)
+                    vector[self.dense_vector_name] = document.embedding
+
+                if self.search_type in [SearchType.keyword, SearchType.hybrid]:
+                    vector[self.sparse_vector_name] = next(self.sparse_encoder.embed([document.content])).as_object()
+
             # Create payload with document properties
             payload = {
                 "name": document.name,
@@ -252,7 +355,7 @@ class Qdrant(VectorDb):
             points.append(
                 models.PointStruct(
                     id=doc_id,
-                    vector=document.embedding,
+                    vector=vector,
                     payload=payload,
                 )
             )
@@ -272,10 +375,26 @@ class Qdrant(VectorDb):
         log_debug(f"Inserting {len(documents)} documents asynchronously")
 
         async def process_document(document):
-            document.embed(embedder=self.embedder)
             cleaned_content = document.content.replace("\x00", "\ufffd")
             doc_id = md5(cleaned_content.encode()).hexdigest()
 
+            if self.search_type == SearchType.vector:
+                # For vector search, maintain backward compatibility with unnamed vectors
+                document.embed(embedder=self.embedder)
+                vector = document.embedding
+            else:
+                # For other search types, use named vectors
+                vector = {}
+                if self.search_type in [SearchType.hybrid]:
+                    document.embed(embedder=self.embedder)
+                    vector[self.dense_vector_name] = document.embedding
+
+                if self.search_type in [SearchType.keyword, SearchType.hybrid]:
+                    vector[self.sparse_vector_name] = next(self.sparse_encoder.embed([document.content])).as_object()
+
+            if self.search_type in [SearchType.keyword, SearchType.hybrid]:
+                vector[self.sparse_vector_name] = next(self.sparse_encoder.embed([document.content])).as_object()
+
             # Create payload with document properties
             payload = {
                 "name": document.name,
@@ -294,7 +413,7 @@ class Qdrant(VectorDb):
             log_debug(f"Inserted document asynchronously: {document.name} ({document.meta_data})")
             return models.PointStruct(
                 id=doc_id,
-                vector=document.embedding,
+                vector=vector,
                 payload=payload,
             )
 
@@ -316,108 +435,223 @@ class Qdrant(VectorDb):
             filters (Optional[Dict[str, Any]]): Filters to apply while upserting
         """
         log_debug("Redirecting the request to insert")
-        self.insert(documents)
+        self.insert(documents, filters)
 
     async def async_upsert(self, documents: List[Document], filters: Optional[Dict[str, Any]] = None) -> None:
         """Upsert documents asynchronously."""
         log_debug("Redirecting the async request to async_insert")
-        await self.async_insert(documents)
+        await self.async_insert(documents, filters)
 
     def search(self, query: str, limit: int = 5, filters: Optional[Dict[str, Any]] = None) -> List[Document]:
         """
-        Search for documents in the database.
+        Search for documents in the collection.
 
         Args:
             query (str): Query to search for
             limit (int): Number of search results to return
             filters (Optional[Dict[str, Any]]): Filters to apply while searching
         """
-        query_embedding = self.embedder.get_embedding(query)
-        if query_embedding is None:
-            logger.error(f"Error getting embedding for Query: {query}")
-            return []
+        filters = self._format_filters(filters or {})
+        if self.search_type == SearchType.vector:
+            results = self._run_vector_search_sync(query, limit, filters)
+        elif self.search_type == SearchType.keyword:
+            results = self._run_keyword_search_sync(query, limit, filters)
+        elif self.search_type == SearchType.hybrid:
+            results = self._run_hybrid_search_sync(query, limit, filters)
+        else:
+            raise ValueError(f"Unsupported search type: {self.search_type}")
 
-        # Build search parameters
-        search_params = {
-            "collection_name": self.collection,
-            "query_vector": query_embedding,
-            "with_vectors": True,
-            "with_payload": True,
-            "limit": limit,
-        }
-
-        # Handle filters if provided - normalize format for Qdrant
-        if filters:
-            filter_conditions = []
-            for key, value in filters.items():
-                # If key contains a dot already, assume it's in the correct format
-                # Otherwise, assume it's a metadata field and add the prefix
-                if "." not in key and not key.startswith("meta_data."):
-                    # This is a simple field name, assume it's metadata
-                    key = f"meta_data.{key}"
-
-                if isinstance(value, dict):
-                    # Handle nested dictionaries
-                    for sub_key, sub_value in value.items():
-                        filter_conditions.append(
-                            models.FieldCondition(key=f"{key}.{sub_key}", match=models.MatchValue(value=sub_value))
-                        )
-                else:
-                    # Handle direct key-value pairs
-                    filter_conditions.append(models.FieldCondition(key=key, match=models.MatchValue(value=value)))
-
-            if filter_conditions:
-                # Use query_filter instead of filter
-                search_params["query_filter"] = models.Filter(must=filter_conditions)
-
-        try:
-            # Execute search with parameters
-            results = self.client.search(**search_params)  # type: ignore
-        except Exception as e:
-            logger.error(f"Error searching for documents: {e}")
-            return []
-
-        # Build search results
-        search_results: List[Document] = []
-        for result in results:
-            if result.payload is None:
-                continue
-            search_results.append(
-                Document(
-                    name=result.payload["name"],
-                    meta_data=result.payload["meta_data"],
-                    content=result.payload["content"],
-                    embedder=self.embedder,
-                    embedding=result.vector,  # type: ignore
-                    usage=result.payload["usage"],
-                )
-            )
-
-        if self.reranker:
-            search_results = self.reranker.rerank(query=query, documents=search_results)
-
-        log_info(f"Found {len(search_results)} documents")
-        return search_results
+        return self._build_search_results(results, query)
 
     async def async_search(
         self, query: str, limit: int = 5, filters: Optional[Dict[str, Any]] = None
     ) -> List[Document]:
-        """Search for documents asynchronously."""
-        query_embedding = self.embedder.get_embedding(query)
-        if query_embedding is None:
-            logger.error(f"Error getting embedding for Query: {query}")
-            return []
+        filters = self._format_filters(filters or {})
+        if self.search_type == SearchType.vector:
+            results = await self._run_vector_search_async(query, limit, filters)
+        elif self.search_type == SearchType.keyword:
+            results = await self._run_keyword_search_async(query, limit, filters)
+        elif self.search_type == SearchType.hybrid:
+            results = await self._run_hybrid_search_async(query, limit, filters)
+        else:
+            raise ValueError(f"Unsupported search type: {self.search_type}")
 
-        # Build search parameters
-        search_params = {
-            "collection_name": self.collection,
-            "query_vector": query_embedding,
-            "with_vectors": True,
-            "with_payload": True,
-            "limit": limit,
-        }
+        return self._build_search_results(results, query)
 
-        # Handle filters if provided - normalize format for Qdrant
+    def _run_hybrid_search_sync(
+        self,
+        query: str,
+        limit: int,
+        filters: Optional[Dict[str, Any]],
+    ) -> List[models.ScoredPoint]:
+        dense_embedding = self.embedder.get_embedding(query)
+        sparse_embedding = next(self.sparse_encoder.embed([query])).as_object()
+        call = self.client.query_points(
+            collection_name=self.collection,
+            prefetch=[
+                models.Prefetch(
+                    query=models.SparseVector(**sparse_embedding),
+                    limit=limit,
+                    using=self.sparse_vector_name,
+                ),
+                models.Prefetch(query=dense_embedding, limit=limit, using=self.dense_vector_name),
+            ],
+            query=models.FusionQuery(fusion=self.hybrid_fusion_strategy),
+            with_vectors=True,
+            with_payload=True,
+            limit=limit,
+            query_filter=filters,
+        )
+        return call.points
+
+    def _run_vector_search_sync(
+        self,
+        query: str,
+        limit: int,
+        filters: Optional[Dict[str, Any]],
+    ) -> List[models.ScoredPoint]:
+        dense_embedding = self.embedder.get_embedding(query)
+
+        # TODO(v2.0.0): Remove this conditional and always use named vectors
+        if self.use_named_vectors:
+            call = self.client.query_points(
+                collection_name=self.collection,
+                query=dense_embedding,
+                with_vectors=True,
+                with_payload=True,
+                limit=limit,
+                query_filter=filters,
+                using=self.dense_vector_name,
+            )
+        else:
+            # Backward compatibility mode - use unnamed vector
+            call = self.client.query_points(
+                collection_name=self.collection,
+                query=dense_embedding,
+                with_vectors=True,
+                with_payload=True,
+                limit=limit,
+                query_filter=filters,
+            )
+        return call.points
+
+    def _run_keyword_search_sync(
+        self,
+        query: str,
+        limit: int,
+        filters: Optional[Dict[str, Any]],
+    ) -> List[models.ScoredPoint]:
+        sparse_embedding = next(self.sparse_encoder.embed([query])).as_object()
+        call = self.client.query_points(
+            collection_name=self.collection,
+            query=models.SparseVector(**sparse_embedding),
+            with_vectors=True,
+            with_payload=True,
+            limit=limit,
+            using=self.sparse_vector_name,
+            query_filter=filters,
+        )
+        return call.points
+
+    async def _run_vector_search_async(
+        self,
+        query: str,
+        limit: int,
+        filters: Optional[Dict[str, Any]],
+    ) -> List[models.ScoredPoint]:
+        dense_embedding = self.embedder.get_embedding(query)
+
+        # TODO(v2.0.0): Remove this conditional and always use named vectors
+        if self.use_named_vectors:
+            call = await self.async_client.query_points(
+                collection_name=self.collection,
+                query=dense_embedding,
+                with_vectors=True,
+                with_payload=True,
+                limit=limit,
+                query_filter=filters,
+                using=self.dense_vector_name,
+            )
+        else:
+            # Backward compatibility mode - use unnamed vector
+            call = await self.async_client.query_points(
+                collection_name=self.collection,
+                query=dense_embedding,
+                with_vectors=True,
+                with_payload=True,
+                limit=limit,
+                query_filter=filters,
+            )
+        return call.points
+
+    async def _run_keyword_search_async(
+        self,
+        query: str,
+        limit: int,
+        filters: Optional[Dict[str, Any]],
+    ) -> List[models.ScoredPoint]:
+        sparse_embedding = next(self.sparse_encoder.embed([query])).as_object()
+        call = await self.async_client.query_points(
+            collection_name=self.collection,
+            query=models.SparseVector(**sparse_embedding),
+            with_vectors=True,
+            with_payload=True,
+            limit=limit,
+            using=self.sparse_vector_name,
+            query_filter=filters,
+        )
+        return call.points
+
+    async def _run_hybrid_search_async(
+        self,
+        query: str,
+        limit: int,
+        filters: Optional[Dict[str, Any]],
+    ) -> List[models.ScoredPoint]:
+        dense_embedding = self.embedder.get_embedding(query)
+        sparse_embedding = next(self.sparse_encoder.embed([query])).as_object()
+        call = await self.async_client.query_points(
+            collection_name=self.collection,
+            prefetch=[
+                models.Prefetch(
+                    query=models.SparseVector(**sparse_embedding),
+                    limit=limit,
+                    using=self.sparse_vector_name,
+                ),
+                models.Prefetch(query=dense_embedding, limit=limit, using=self.dense_vector_name),
+            ],
+            query=models.FusionQuery(fusion=self.hybrid_fusion_strategy),
+            with_vectors=True,
+            with_payload=True,
+            limit=limit,
+            query_filter=filters,
+        )
+        return call.points
+
+    def _build_search_results(self, results, query: str) -> List[Document]:
+        search_results: List[Document] = []
+
+        for result in results:
+            if result.payload is None:
+                continue
+            search_results.append(
+                Document(
+                    name=result.payload["name"],
+                    meta_data=result.payload["meta_data"],
+                    content=result.payload["content"],
+                    embedder=self.embedder,
+                    embedding=result.vector,  # type: ignore
+                    usage=result.payload["usage"],
+                )
+            )
+
+        if self.reranker:
+            search_results = self.reranker.rerank(query=query, documents=search_results)
+
+        log_info(f"Found {len(search_results)} documents")
+        return search_results
+
+    def _format_filters(self, filters: Optional[Dict[str, Any]]) -> Optional[models.Filter]:
         if filters:
             filter_conditions = []
             for key, value in filters.items():
@@ -438,37 +672,9 @@ class Qdrant(VectorDb):
                     filter_conditions.append(models.FieldCondition(key=key, match=models.MatchValue(value=value)))
 
             if filter_conditions:
-                # Use query_filter instead of filter
-                search_params["query_filter"] = models.Filter(must=filter_conditions)
+                return models.Filter(must=filter_conditions)
 
-        try:
-            # Execute search with parameters
-            results = await self.async_client.search(**search_params)  # type: ignore
-        except Exception as e:
-            logger.error(f"Error searching for documents: {e}")
-            return []
-
-        # Build search results
-        search_results: List[Document] = []
-        for result in results:
-            if result.payload is None:
-                continue
-            search_results.append(
-                Document(
-                    name=result.payload["name"],
-                    meta_data=result.payload["meta_data"],
-                    content=result.payload["content"],
-                    embedder=self.embedder,
-                    embedding=result.vector,  # type: ignore
-                    usage=result.payload["usage"],
-                )
-            )
-
-        if self.reranker:
-            search_results = self.reranker.rerank(query=query, documents=search_results)
-
-        log_info(f"Found {len(search_results)} documents")
-        return search_results
+        return None
 
     def drop(self) -> None:
         if self.exists():
@@ -482,23 +688,12 @@ class Qdrant(VectorDb):
             await self.async_client.delete_collection(self.collection)
 
     def exists(self) -> bool:
-        if self.client:
-            collections_response: models.CollectionsResponse = self.client.get_collections()
-            collections: List[models.CollectionDescription] = collections_response.collections
-            for collection in collections:
-                if collection.name == self.collection:
-                    # collection.status == models.CollectionStatus.GREEN
-                    return True
-        return False
+        """Check if the collection exists."""
+        return self.client.collection_exists(collection_name=self.collection)
 
     async def async_exists(self) -> bool:
         """Check if the collection exists asynchronously."""
-        collections_response = await self.async_client.get_collections()
-        collections: List[models.CollectionDescription] = collections_response.collections
-        for collection in collections:
-            if collection.name == self.collection:
-                return True
-        return False
+        return await self.async_client.collection_exists(collection_name=self.collection)
 
     def get_count(self) -> int:
         count_result: models.CountResult = self.client.count(collection_name=self.collection, exact=True)
@@ -508,4 +703,4 @@ class Qdrant(VectorDb):
         pass
 
     def delete(self) -> bool:
-        return False
+        return self.client.delete_collection(collection_name=self.collection)
