@@ -1 +1,5 @@
 from agno.vectordb.upstashdb.upstashdb import UpstashVectorDb
+
+__all__ = [
+    "UpstashVectorDb",
+]
